@@ -18,7 +18,7 @@ namespace Views {
     doubleClickAction=new Lum::Model::Action;
     Observe(doubleClickAction);
 
-    model=new Lum::Model::ListTable();
+    model=new Lum::Model::StringTable();
 
     table=new Lum::Table();
     table->SetModel(model);
@@ -93,11 +93,7 @@ namespace Views {
 
     iter=views.begin();
     while (iter!=views.end()) {
-      Lum::Model::ListTable::StdEntry* entry;
-
-      entry=new Lum::Model::ListTable::StdEntry(model);
-      entry->SetString(1,(*iter)->GetName());
-      model->Append(entry);
+      model->Append((*iter)->GetName());
 
       iter++;
     }
